@@ -35,5 +35,5 @@ class GuardianAdminMixin:
     #         qs = qs.order_by(*ordering)
     #     return qs
 
-class GuardianModelAdmin(admin.ModelAdmin, GuardianAdminMixin):
+class GuardianModelAdmin(GuardianAdminMixin, admin.ModelAdmin):
     pass
\ No newline at end of file
