@@ -11,8 +11,8 @@ def get_model_name(obj_or_query):
     except Exception:
         return obj_or_query._meta.model.__name__.lower()
 
-def assign_default_permissions(user, object):
-    model_name = get_model_name(object)
+def assign_default_permissions(user, object, model_name=None):
+    model_name = model_name or get_model_name(object)
     assign_perm('view_' + model_name, user, object)
     assign_perm('change_' + model_name, user, object)
     assign_perm('delete_' + model_name, user, object)
